// dependencies:
const configureStore = require('redux-mock-store').default;
// utilities:
const simplerReduxPromise = require('../index');

const middleware = [simplerReduxPromise];
const mockStore = configureStore(middleware);
const promise = new Promise((resolve, reject) => {
    resolve('promises promises...');
});

it('is defined', () => {
    expect(simplerReduxPromise).toBeDefined();
});

describe('simpler-redux-middleware', () => {
    let initialState, store, timeout;

    beforeEach(() => {
        initialState = { };
        store = mockStore(initialState);
        timeout = 0;
    });

    it('ignores non-promises', (done) => {
        store.dispatch({
            type: 'placeholder',
            nonPromise: 'nonPromises nonPromises...',
        });
        setTimeout(() => {
            expect(store.getActions()).toEqual([{
                type: 'placeholder',
                nonPromise: 'nonPromises nonPromises...',
            }]);
            done();
        }, timeout);
    });

    it('resolves promises', (done) => {
        store.dispatch({
            type: 'placeholder',
            promise: promise,
        });
        setTimeout(() => {
            expect(store.getActions()).toEqual([{
                type: 'placeholder',
                promise: 'promises promises...',
            }]);
            done();
        }, timeout);
    });

    it('resolves promises and ignores non-promises', (done) => {
        store.dispatch({
            type: 'placeholder',
            promise: promise,
            nonPromise: 'nonPromises nonPromises...',
        });
        setTimeout(() => {
            expect(store.getActions()).toEqual([{
                type: 'placeholder',
                promise: 'promises promises...',
                nonPromise: 'nonPromises nonPromises...',
            }]);
            done();
        }, timeout);
    });

    it('resolves multiple promises', (done) => {
        store.dispatch({
            type: 'placeholder',
            promise: promise,
            promise2: promise,
        });
        setTimeout(() => {
            expect(store.getActions()).toEqual([{
                type: 'placeholder',
                promise: 'promises promises...',
                promise2: 'promises promises...',
            }]);
            done();
        }, timeout);
    });
});
